<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">

          <el-col :span="5">
            <el-form-item label="受检单位">
              <el-input v-model="querys[0].value" clearable placeholder="请输入受检单位名称" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="受检单位负责人">
              <el-input v-model="querys[1].value" clearable placeholder="请输入受检单位名称" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="检查人员">
              <el-input v-model="querys[2].value" clearable placeholder="请输入受检单位名称" />
            </el-form-item>
          </el-col>
          <!--          <el-col :span="5">-->
          <!--            <el-form-item label="检查日期">-->
          <!--              <el-date-picker v-model="querys[3].value" placeholder="请选择检查日期" style="width:100%;" type="date"-->
          <!--                              value-format="yyyy" />-->
          <!--            </el-form-item>-->
          <!--          </el-col>-->
          <el-col :span="4">
            <el-button icon="el-icon-search" type="primary" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div ref="contentPanel" class="bbsl-table-content">
      <div ref="btnPanel" class="bbsl-btn-content">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete"
                     style="margin-left: 10px"
                     type="danger">删除
          </el-button>
        </el-popconfirm>
      </div>
      <el-table ref="multipleSelection" v-loading="loading" :cell-style="{ 'text-align': 'center' }" :data="tableData"
                :header-cell-style="{ 'text-align': 'center' }"
                :max-height="tableMaxHeight" :style="{ width: '100%' }" border
                size="mini" @row-dblclick="handleDbClick"
                @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column fixed label="序号" type="index" width="55"></el-table-column>
        <!--        <el-table-column label="受检单位名称" min-width="70" prop="targetYear" show-overflow-tooltip-->
        <!--                         sortable></el-table-column>-->
        <el-table-column label="受检单位名称" min-width="120" prop="clientUnitName"
                         show-overflow-tooltip></el-table-column>
        <el-table-column label="受检单位负责人" min-width="100" prop="clientUserName"
                         show-overflow-tooltip></el-table-column>
        <el-table-column label="受检单位联系电话" min-width="150" prop="clientTel"
                         show-overflow-tooltip></el-table-column>
        <el-table-column label="检查日期" min-width="150" prop="clientDate" show-overflow-tooltip></el-table-column>
        <el-table-column label="检查人员" min-width="60" prop="examineUserName" show-overflow-tooltip></el-table-column>
        <el-table-column label="正常数" min-width="60" prop="trueNum" show-overflow-tooltip></el-table-column>
        <el-table-column label="隐患数" min-width="60" prop="hiddenNum" show-overflow-tooltip></el-table-column>
      </el-table>
      <el-pagination ref="paginationPanel" :current-page="queryParam.pageBean.page"
                     :page-size="queryParam.pageBean.pageSize" :page-sizes="[20, 30, 40, 50]"
                     :total="total" align="right"
                     background
                     class="bbsl-pagination" layout="total, sizes, prev, pager, next, jumper"
                     @size-change="handleSizeChange" @current-change="handleCurrentChange"></el-pagination>
    </div>
    <CmgTSaftyHazardCheckManageDialog ref="formModal"
                                      @save-success="handleSaveSuccess"></CmgTSaftyHazardCheckManageDialog>
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'

import API from '@/views/Manage/saftyPlan/api/CmgTSaftyHazardCheckApi'
import CmgTSaftyHazardCheckManageDialog from '@/views/Manage/saftyPlan/components/CmgTSaftyHazardCheckManageDialog.vue'
import req from '@/request.js'

export default {
  name: 'CmgtSaftyTargetManage',
  components: {
    CmgTSaftyHazardCheckManageDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/cmgtSafeCheckHolidays/v1/delete/ids'
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'sdu.unit_name_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'sch.CLIENT_USER_NAME_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'sch.EXAMINE_USER_NAME_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'sch.CLIENT_DATE_',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      fuelTypes: [],
      aqywlbList: []
    }
  },
  created() {
    this.aqywlbList = dictUtils.getDictItemsFromCache('aqywlb')
  },
  mounted() {
  },
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
    },
    // 获取list
    loadData(page) {
      console.log(1111111)
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      console.log('请求参数:', this.queryParam)
      API.CmgTSaftyHazardCheckList(this.queryParam, res => {
        console.log('响应数据', res)
        this.total = res.total
        this.tableData = res.rows
        this.loading = false
      })
    },

    // 修改
    handleUpdate(row) {
      console.log('双击行数据:', row)
      if (row.id) {
        this.$refs.formModal.Update(row)
      } else {
        console.error('行数据中缺少 id 字段')
      }
    },

    closeStshowForm() {
      this.StshowFormDias = false
    },
    handleSaveSuccess() {
      this.loadData() // 刷新列表数据
    },
    handleDelete() {
      // 批量删除
      const ids = this.multipleSelection.join(',')
      const url = `${this.portal}${this.url.delete}?ids=${ids}`
      req.post(url)
        .then(res => {
          this.$notify({
            type: 'success',
            message: '删除成功',
            duration: 2000
          })
          this.loadData()
          this.handleDeleteAfter && this.handleDeleteAfter()
        })
        .catch(error => {
          console.error('删除失败:', error)
          this.$message.error('删除失败，请稍后重试')
        })
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
